@@ -43,9 +43,6 @@ trap 'echo SIGTERM received' TERM
 
 {{prologue}}
 
-# Custom R
-{% if req_custom_r    %}export PATH="{{req_custom_r}}:$PATH"{% endif %}
-
 which jupyterhub-singleuser
 {% if srun %}{{srun}} {% endif %}{{cmd}}
 echo "jupyterhub-singleuser ended gracefully"
@@ -317,7 +314,8 @@ echo "jupyterhub-singleuser ended gracefully"
         sinfo = SInfoTable()
         df = sinfo.dataframe
         df.sort_values(by=["mem", "vcpu", "cpu", "queue"], inplace=True)
-        sinfo.dataframe = df
+        sinfo = SInfoTable(dataframe=df)
+        # sinfo.dataframe = df
         return sinfo
 
     @property
@@ -395,18 +393,6 @@ echo "jupyterhub-singleuser ended gracefully"
     <label for="options">Options (additional options such as -N 4 for multiple nodes)</label>
     <input type="text" class="form-control" value="{{req_options}}" placeholder="{req_options}" id="options" name="req_options"/>
 </div>
-
-<div class="form-group">
-    <label for="custom_env">Custom Env (spack load my-env). You should only need this option for custom R environments!</label>
-    <textarea id="custom_env" name="req_custom_env" rows="4" cols="50">
-    {{req_custom_env}}
-    </textarea>
-</div>
-
-<div class="form-group">
-    <label for="custom_r_path">Custom R Path (Run source activate my-r-env; which R)</label>
-    <input type="text" class="form-control" value="{{req_custom_r}}" placeholder="" id="custom_r" name="req_custom_r"/>
-</div>
     """
         rtemplate = Environment(loader=BaseLoader).from_string(form_options)
         return rtemplate.render(**defaults)
@@ -446,6 +432,11 @@ echo "jupyterhub-singleuser ended gracefully"
         for key in submission_data.keys():
             setattr(self, key, submission_data[key])
 
+        if "req_custom_env" in submission_data.keys():
+            l = submission_data["req_custom_env"]
+            l = "\n".join(l.splitlines())
+            submission_data["req_custom_env"] = l
+
         if "req_custom_r" in submission_data.keys():
             custom_r = submission_data["req_custom_r"]
             custom_r = os.path.split(custom_r)
